@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-cf54ac8d6eb4d9105572f96531f5239b
-key: yesod_A7UlYB5EUo9GyIvhyZIq8a
+id: yesod-1.4.2-67829aa7ba8c4341f8add31623e957be
+key: yesod_9jHuMsQ6BQCLASH1vVAEEA
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,22 +21,22 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-A7UlYB5EUo9GyIvhyZIq8a
+hs-libraries: HSyesod-1.4.2-9jHuMsQ6BQCLASH1vVAEEA
 depends:
-    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
+    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
+    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-ff79344a77beba20df980e6518219c42
+    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
+    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
     streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.14.1-3d73c8398a11a38d4e003b75a7dec448
+    wai-extra-3.0.14.1-5f3982898a5be41036c34bae0277136d
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-f00ff5bb4c1a36e982e04bfba3bef2ca
-    yaml-0.8.16-9d8e48229c43339be2171b93f8cd276c
-    yesod-auth-1.4.12-bd2dbd422b8b288b6daf1ac8f5cb89f3
-    yesod-core-1.4.19-824bf74cd5ec378da568ce71e584e959
-    yesod-form-1.4.6-cc7fd5c2de84bb46c0f6247cd76452a8
-    yesod-persistent-1.4.0.3-cff443ae4acaed8c9376536a5719bdb9
+    warp-3.2.3-e779983be81de2d2755ab5db7108dace
+    yaml-0.8.16-d3d7ff6fb3ea07062f7f4203706ad9cb
+    yesod-auth-1.4.12-4d0ca9693c853dd4d68086b010a1e6bd
+    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
+    yesod-form-1.4.6-33df701f6ce354a3ae16e9cd594ae06c
+    yesod-persistent-1.4.0.3-8395aca265c8d812b1837a7679a2306f
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
